// libcurl-header.sma
//
// Copyright © 2011-2020 Superbase Software Limited, all rights reserved.
// Author: Neil Robinson, Michael Ott, Nikolaus Zolnhofer
//
// Description:
// ============
// This is the header file for the libcurl component, not everything is 
// currently ported from the curl.h file
//////////////////////////////////////////////////////////////////////////////

////////////////////////////////////  CURL Errors  //////////////////////////////////////

constant CURLE_OK                           0
constant CURLE_UNSUPPORTED_PROTOCOL         1
constant CURLE_FAILED_INIT                  2
constant CURLE_URL_MALFORMAT                3
constant CURLE_NOT_BUILT_IN                 4; // - [was obsoleted in August 2007 for
                                               // 7.17.0, reused in April 2011 for 7.21.5]
constant CURLE_COULDNT_RESOLVE_PROXY        5
constant CURLE_COULDNT_RESOLVE_HOST         6
constant CURLE_COULDNT_CONNECT              7
constant CURLE_FTP_WEIRD_SERVER_REPLY       8
constant CURLE_REMOTE_ACCESS_DENIED         9 ; // a service was denied by the server
                                               // due to lack of access - when login fails
                                               // this is not returned.
constant CURLE_OBSOLETE10                  10 ; // - NOT USED */
constant CURLE_FTP_WEIRD_PASS_REPLY        11
constant CURLE_OBSOLETE12                  12 ; // - NOT USED */
constant CURLE_FTP_WEIRD_PASV_REPLY        13
constant CURLE_FTP_WEIRD_227_FORMAT        14
constant CURLE_FTP_CANT_GET_HOST           15
constant CURLE_OBSOLETE16                  16 ; // - NOT USED */
constant CURLE_FTP_COULDNT_SET_TYPE        17
constant CURLE_PARTIAL_FILE                18
constant CURLE_FTP_COULDNT_RETR_FILE       19
constant CURLE_OBSOLETE20                  20 ; // - NOT USED */
constant CURLE_QUOTE_ERROR                 21 ; // - quote command failure */
constant CURLE_HTTP_RETURNED_ERROR         22
constant CURLE_WRITE_ERROR                 23
constant CURLE_OBSOLETE24                  24 ; // - NOT USED */
constant CURLE_UPLOAD_FAILED               25 ; // - failed upload "command" */
constant CURLE_READ_ERROR                  26 ; // - couldn't open/read from file */
constant CURLE_OUT_OF_MEMORY               27
  //   Note: CURLE_OUT_OF_MEMORY may sometimes indicate a conversion error
  //         instead of a memory allocation error if CURL_DOES_CONVERSIONS
  //         is defined

constant CURLE_OPERATION_TIMEDOUT          28 ; // - the timeout time was reached */
constant CURLE_OBSOLETE29                  29 ; // - NOT USED */
constant CURLE_FTP_PORT_FAILED             30 ; // - FTP PORT operation failed */
constant CURLE_FTP_COULDNT_USE_REST        31 ; // - the REST command failed */
constant CURLE_OBSOLETE32                  32 ; // - NOT USED */
constant CURLE_RANGE_ERROR                 33 ; // - RANGE "command" didn't work */
constant CURLE_HTTP_POST_ERROR             34
constant CURLE_SSL_CONNECT_ERROR           35 ; // - wrong when connecting with SSL */
constant CURLE_BAD_DOWNLOAD_RESUME         36 ; // - couldn't resume download */
constant CURLE_FILE_COULDNT_READ_FILE      37
constant CURLE_LDAP_CANNOT_BIND            38
constant CURLE_LDAP_SEARCH_FAILED          39
constant CURLE_OBSOLETE40                  40 ; // - NOT USED */
constant CURLE_FUNCTION_NOT_FOUND          41
constant CURLE_ABORTED_BY_CALLBACK         42
constant CURLE_BAD_FUNCTION_ARGUMENT       43
constant CURLE_OBSOLETE44                  44 ; // - NOT USED */
constant CURLE_INTERFACE_FAILED            45 ; // - CURLOPT_INTERFACE failed */
constant CURLE_OBSOLETE46                  46 ; // - NOT USED */
constant CURLE_TOO_MANY_REDIRECTS          47 ; // - catch endless re-direct loops */
constant CURLE_UNKNOWN_OPTION              48 ; // - User specified an unknown option */
constant CURLE_TELNET_OPTION_SYNTAX        49 ; // - Malformed telnet option */
constant CURLE_OBSOLETE50                  50 ; // - NOT USED */
constant CURLE_PEER_FAILED_VERIFICATION    51 ; // - peer's certificate or fingerprint
                                                //   wasn't verified fine */
constant CURLE_GOT_NOTHING                 52 ; // - when this is a specific error */
constant CURLE_SSL_ENGINE_NOTFOUND         53 ; // - SSL crypto engine not found */
constant CURLE_SSL_ENGINE_SETFAILED        54 ; // - can not set SSL crypto engine as
                                                //   default */
constant CURLE_SEND_ERROR                  55 ; // - failed sending network data */
constant CURLE_RECV_ERROR                  56 ; // - failure in receiving network data */
constant CURLE_OBSOLETE57                  57 ; // - NOT IN USE */
constant CURLE_SSL_CERTPROBLEM             58 ; // - problem with the local certificate */
constant CURLE_SSL_CIPHER                  59 ; // - couldn't use specified cipher */
constant CURLE_SSL_CACERT                  60 ; // - problem with the CA cert (path?) */
constant CURLE_BAD_CONTENT_ENCODING        61 ; // - Unrecognized/bad encoding */
constant CURLE_LDAP_INVALID_URL            62 ; // - Invalid LDAP URL */
constant CURLE_FILESIZE_EXCEEDED           63 ; // - Maximum file size exceeded */
constant CURLE_USE_SSL_FAILED              64 ; // - Requested FTP SSL level failed */
constant CURLE_SEND_FAIL_REWIND            65 ; // - Sending the data requires a rewind
                                                //   that failed */
constant CURLE_SSL_ENGINE_INITFAILED       66 ; // - failed to initialise ENGINE */
constant CURLE_LOGIN_DENIED                67 ; // - user, password or similar was not
                                                //   accepted and we failed to login */
constant CURLE_TFTP_NOTFOUND               68 ; // - file not found on server */
constant CURLE_TFTP_PERM                   69 ; // - permission problem on server */
constant CURLE_REMOTE_DISK_FULL            70 ; // - out of disk space on server */
constant CURLE_TFTP_ILLEGAL                71 ; // - Illegal TFTP operation */
constant CURLE_TFTP_UNKNOWNID              72 ; // - Unknown transfer ID */
constant CURLE_REMOTE_FILE_EXISTS          73 ; // - File already exists */
constant CURLE_TFTP_NOSUCHUSER             74 ; // - No such user */
constant CURLE_CONV_FAILED                 75 ; // - conversion failed */
constant CURLE_CONV_REQD                   76 ; // - caller must register conversion
                                                //   callbacks using curl_easy_setopt options
                                                //   CURLOPT_CONV_FROM_NETWORK_FUNCTION,
                                                //   CURLOPT_CONV_TO_NETWORK_FUNCTION, and
                                                //   CURLOPT_CONV_FROM_UTF8_FUNCTION */
constant CURLE_SSL_CACERT_BADFILE          77 ; // - could not load CACERT file, missing
                                                //   or wrong format */
constant CURLE_REMOTE_FILE_NOT_FOUND       78 ; // - remote file not found */
constant CURLE_SSH                         79 ; // - error from the SSH layer, somewhat
                                                //   generic so the error message will be of
                                                //   interest when this has happened */

constant CURLE_SSL_SHUTDOWN_FAILED         80 ; // - Failed to shut down the SSL
                                                //   connection */
constant CURLE_AGAIN                       81 ; // - socket is not ready for send/recv,
                                                //   wait till it's ready and try again (Added
                                                //   in 7.18.2) */
constant CURLE_SSL_CRL_BADFILE             82 ; // - could not load CRL file, missing or
                                                //   wrong format (Added in 7.19.0) */
constant CURLE_SSL_ISSUER_ERROR            83 ; // - Issuer check failed.  (Added in
                                                //   7.19.0) */
constant CURLE_FTP_PRET_FAILED             84 ; // - a PRET command failed */
constant CURLE_RTSP_CSEQ_ERROR             85 ; // - mismatch of RTSP CSeq numbers */
constant CURLE_RTSP_SESSION_ERROR          86 ; // - mismatch of RTSP Session Ids */
constant CURLE_FTP_BAD_FILE_LIST           87 ; // - unable to parse FTP file list */
constant CURLE_CHUNK_FAILED                88 ; // - chunk callback reported error */
