// libcurl-header.sma
//
// Copyright © 2011-2020 Superbase Software Limited, all rights reserved.
// Author: Neil Robinson, Michael Ott, Nikolaus Zolnhofer
//
// Description:
// ============
// This is the header file for the libcurl component, not everything is 
// currently ported from the curl.h file
//////////////////////////////////////////////////////////////////////////////

////////////////////////////////////  CURL Options  //////////////////////////////////////


  // This is the FILE * or void * the regular output should be written to. */
constant CURLOPT_FILE  10001

  // The full URL to get/put */
constant CURLOPT_URL   10002

  // Port number to connect to, if other than default. */
constant CURLOPT_PORT  3

  // Name of proxy to use. */
constant CURLOPT_PROXY  10004

  // "name:password" to use when fetching. */
constant CURLOPT_USERPWD  10005

  // "name:password" to use with proxy. */
constant CURLOPT_PROXYUSERPWD  10006

  // Range to get, specified as an ASCII string. */
constant CURLOPT_RANGE  10007

  // not used */

  // Specified file stream to upload from (use as input): */
constant CURLOPT_INFILE  10009

  // Buffer to receive error messages in, must be at least CURL_ERROR_SIZE
  // bytes big. If this is not used, error messages go to stderr instead: */
constant CURLOPT_ERRORBUFFER  10010

  // Function that will be called to store the output (instead of fwrite). The
  // parameters will use fwrite() syntax, make sure to follow them. */
constant CURLOPT_WRITEFUNCTION  20011

  // Function that will be called to read the input (instead of fread). The
  // parameters will use fread() syntax, make sure to follow them. */
constant CURLOPT_READFUNCTION  20012

  // Time-out the read operation after this amount of seconds */
constant CURLOPT_TIMEOUT  13

  // If the CURLOPT_INFILE is used, this can be used to inform libcurl about
  // how large the file being sent really is. That allows better error
  // checking and better verifies that the upload was successful. -1 means
  // unknown size.
  //
  // For large file support, there is also a _LARGE version of the key
  // which takes an off_t type, allowing platforms with larger off_t
  // sizes to handle larger files.  See below for INFILESIZE_LARGE.

constant CURLOPT_INFILESIZE  14

  // POST static input fields. */
constant CURLOPT_POSTFIELDS  10015

  // Set the referrer page (needed by some CGIs) */
constant CURLOPT_REFERER  10016

  // Set the FTP PORT string (interface name, named or numerical IP address)
  // Use i.e '-' to use default address. */
constant CURLOPT_FTPPORT  10017

  // Set the User-Agent string (examined by some CGIs) */
constant CURLOPT_USERAGENT  10018

  // If the download receives less than "low speed limit" bytes/second
  // during "low speed time" seconds, the operations is aborted.
  // You could i.e if you have a pretty high speed connection, abort if
  // it is less than 2000 bytes/sec during 20 seconds.

  // Set the "low speed limit" */
constant CURLOPT_LOW_SPEED_LIMIT  19

  // Set the "low speed time" */
constant CURLOPT_LOW_SPEED_TIME  20

  // Set the continuation offset.
  //
  // Note there is also a _LARGE version of this key which uses
  // off_t types, allowing for large file offsets on platforms which
  // use larger-than-32-bit off_t's.  Look below for RESUME_FROM_LARGE.

constant CURLOPT_RESUME_FROM  21

  // Set cookie in request: */
constant CURLOPT_COOKIE  10022

  // This points to a linked list of headers, struct curl_slist kind */
constant CURLOPT_HTTPHEADER  10023

  // This points to a linked list of post entries, struct curl_httppost */
constant CURLOPT_HTTPPOST  10024

  // name of the file keeping your private SSL-certificate */
constant CURLOPT_SSLCERT  10025

  // password for the SSL or SSH private key */
constant CURLOPT_KEYPASSWD  10026

  // send TYPE parameter? */
constant CURLOPT_CRLF  27

  // send linked-list of QUOTE commands */
constant CURLOPT_QUOTE  10028

  // send FILE * or void * to store headers to, if you use a callback it
  // is simply passed to the callback unmodified */
constant CURLOPT_WRITEHEADER  10029

  // point to a file to read the initial cookies from, also enables
  // "cookie awareness" */
constant CURLOPT_COOKIEFILE  10031

  // What version to specifically try to use.
  // See CURL_SSLVERSION defines below. */
constant CURLOPT_SSLVERSION  32

  // What kind of HTTP time condition to use, see defines */
constant CURLOPT_TIMECONDITION  33

  // Time to use with the above condition. Specified in number of seconds
  // since 1 Jan 1970 */
constant CURLOPT_TIMEVALUE  34

  // 35 = OBSOLETE */

  // Custom request, for customizing the get command like
  // HTTP: DELETE, TRACE and others
  // FTP: to use a different list command

constant CURLOPT_CUSTOMREQUEST  10036

  // HTTP request, for odd commands like DELETE, TRACE and others */
constant CURLOPT_STDERR  10037

  // 38 is not used */

  // send linked-list of post-transfer QUOTE commands */
constant CURLOPT_POSTQUOTE  10039

  // Pass a pointer to string of the output using full variable-replacement
  // as described elsewhere. */
constant CURLOPT_WRITEINFO  10040

constant CURLOPT_VERBOSE  41      ;// talk a lot */
constant CURLOPT_HEADER  42       ;// throw the header out too */
constant CURLOPT_NOPROGRESS  43   ;// shut off the progress meter */
constant CURLOPT_NOBODY  44       ;// use HEAD to get http document */
constant CURLOPT_FAILONERROR  45  ;// no output on http error codes >= 300 */
constant CURLOPT_UPLOAD  46       ;// this is an upload */
constant CURLOPT_POST  47         ;// HTTP POST method */
constant CURLOPT_DIRLISTONLY  48  ;// bare names when listing directories */

constant CURLOPT_APPEND  50       ;// Append instead of overwrite on upload! */

  // Specify whether to read the user+password from the .netrc or the URL.
  // This must be one of the CURL_NETRC_* enums below. */
constant CURLOPT_NETRC  51

constant CURLOPT_FOLLOWLOCATION  52  ;// use Location: Luke! */

constant CURLOPT_TRANSFERTEXT  53 ;// transfer data in text/ASCII format */
constant CURLOPT_PUT  54          ;// HTTP PUT */

  // 55 = OBSOLETE */

  // Function that will be called instead of the internal progress display
  // function. This function should be defined as the curl_progress_callback
  // prototype defines. */
constant CURLOPT_PROGRESSFUNCTION  20056

  // Data passed to the progress callback */
constant CURLOPT_PROGRESSDATA  10057

  // We want the referrer field set automatically when following locations */
constant CURLOPT_AUTOREFERER  58

  // Port of the proxy, can be set in the proxy string as well with:
  // "[host]:[port]" */
constant CURLOPT_PROXYPORT  59

  // size of the POST input data, if strlen() is not good to use */
constant CURLOPT_POSTFIELDSIZE  60

  // tunnel non-http operations through a HTTP proxy */
constant CURLOPT_HTTPPROXYTUNNEL  61

  // Set the interface string to use as outgoing network interface */
constant CURLOPT_INTERFACE  10062

  // Set the krb4/5 security level, this also enables krb4/5 awareness.  This
  // is a string, 'clear', 'safe', 'confidential' or 'private'.  If the string
  // is set but doesn't match one of these, 'private' will be used.  */
constant CURLOPT_KRBLEVEL  10063

  // Set if we should verify the peer in ssl handshake, set 1 to verify. */
constant CURLOPT_SSL_VERIFYPEER  64

  // The CApath or CAfile used to validate the peer certificate
  // this option is used only if SSL_VERIFYPEER is true */
constant CURLOPT_CAINFO  10065

  // 66 = OBSOLETE */
  // 67 = OBSOLETE */

  // Maximum number of http redirects to follow */
constant CURLOPT_MAXREDIRS  68

  // Pass a long set to 1 to get the date of the requested document (if
  // possible)! Pass a zero to shut it off. */
constant CURLOPT_FILETIME  69

  // This points to a linked list of telnet options */
constant CURLOPT_TELNETOPTIONS  10070

  // Max amount of cached alive connections */
constant CURLOPT_MAXCONNECTS  71

  // 72 - DEPRECATED */
constant CURLOPT_CLOSEPOLICY  72

  // 73 = OBSOLETE */

  // Set to explicitly use a new connection for the upcoming transfer.
  // Do not use this unless you're absolutely sure of this, as it makes the
  // operation slower and is less friendly for the network. */
constant CURLOPT_FRESH_CONNECT  74

  // Set to explicitly forbid the upcoming transfer's connection to be re-used
  // when done. Do not use this unless you're absolutely sure of this, as it
  // makes the operation slower and is less friendly for the network. */
constant CURLOPT_FORBID_REUSE  75

  // Set to a file name that contains random data for libcurl to use to
  // seed the random engine when doing SSL connects. */
constant CURLOPT_RANDOM_FILE  10076

  // Set to the Entropy Gathering Daemon socket pathname */
constant CURLOPT_EGDSOCKET  10077

  // Time-out connect operations after this amount of seconds, if connects
  // are OK within this time, then fine... This only aborts the connect
  // phase. [Only works on unix-style/SIGALRM operating systems] */
constant CURLOPT_CONNECTTIMEOUT  78

  // Function that will be called to store headers (instead of fwrite). The
  // parameters will use fwrite() syntax, make sure to follow them. */
constant CURLOPT_HEADERFUNCTION  20079

  // Set this to force the HTTP request to get back to GET. Only really usable
  // if POST, PUT or a custom request have been used first.

constant CURLOPT_HTTPGET  80

  // Set if we should verify the Common name from the peer certificate in ssl
  // handshake, set 1 to check existence, 2 to ensure that it matches the
  // provided hostname. */
constant CURLOPT_SSL_VERIFYHOST  81

  // Specify which file name to write all known cookies in after completed
  // operation. Set file name to "-" (dash) to make it go to stdout. */
constant CURLOPT_COOKIEJAR  10082

  // Specify which SSL ciphers to use */
constant CURLOPT_SSL_CIPHER_LIST  10083

  // Specify which HTTP version to use! This must be set to one of the
  // CURL_HTTP_VERSION* enums set below. */
constant CURLOPT_HTTP_VERSION  84

  // Specifically switch on or off the FTP engine's use of the EPSV command. By
  // default, that one will always be attempted before the more traditional
  // PASV command. */
constant CURLOPT_FTP_USE_EPSV  85

  // type of the file keeping your SSL-certificate ("DER", "PEM", "ENG") */
constant CURLOPT_SSLCERTTYPE  10086

  // name of the file keeping your private SSL-key */
constant CURLOPT_SSLKEY  10087

  // type of the file keeping your private SSL-key ("DER", "PEM", "ENG") */
constant CURLOPT_SSLKEYTYPE  10088

  // crypto engine for the SSL-sub system */
constant CURLOPT_SSLENGINE  10089

  // set the crypto engine for the SSL-sub system as default
  // the param has no meaning...

constant CURLOPT_SSLENGINE_DEFAULT  90

  // Non-zero value means to use the global dns cache */
constant CURLOPT_DNS_USE_GLOBAL_CACHE  91; // To become OBSOLETE soon */

  // DNS cache timeout */
constant CURLOPT_DNS_CACHE_TIMEOUT  92

  // send linked-list of pre-transfer QUOTE commands */
constant CURLOPT_PREQUOTE  10093

  // set the debug function */
constant CURLOPT_DEBUGFUNCTION  20094

  // set the data for the debug function */
constant CURLOPT_DEBUGDATA  10095

  // mark this as start of a cookie session */
constant CURLOPT_COOKIESESSION  96

  // The CApath directory used to validate the peer certificate
  // this option is used only if SSL_VERIFYPEER is true */
constant CURLOPT_CAPATH  10097

  // Instruct libcurl to use a smaller receive buffer */
constant CURLOPT_BUFFERSIZE  98

  // Instruct libcurl to not use any signal/alarm handlers, even when using
  // timeouts. This option is useful for multi-threaded applications.
  // See libcurl-the-guide for more background information. */
constant CURLOPT_NOSIGNAL  99

  // Provide a CURLShare for mutexing non-ts data */
constant CURLOPT_SHARE  10100

  // indicates type of proxy. accepted values are CURLPROXY_HTTP (default
  // CURLPROXY_SOCKS4, CURLPROXY_SOCKS4A and CURLPROXY_SOCKS5. */
constant CURLOPT_PROXYTYPE  101

  // Set the Accept-Encoding string. Use this to tell a server you would like
  // the response to be compressed. Before 7.21.6, this was known as
  // CURLOPT_ENCODING */
constant CURLOPT_ACCEPT_ENCODING  10102

  // Set pointer to private data */
constant CURLOPT_PRIVATE  10103

  // Set aliases for HTTP 200 in the HTTP Response header */
constant CURLOPT_HTTP200ALIASES  10104

  // Continue to send authentication (user+password) when following locations,
  // even when hostname changed. This can potentially send off the name
  // and password to whatever host the server decides. */
constant CURLOPT_UNRESTRICTED_AUTH  105

  // Specifically switch on or off the FTP engine's use of the EPRT command (
  // it also disables the LPRT attempt). By default, those ones will always be
  // attempted before the good old traditional PORT command. */
constant CURLOPT_FTP_USE_EPRT  106

  // Set this to a bitmask value to enable the particular authentications
  // methods you like. Use this in combination with CURLOPT_USERPWD.
  // Note that setting multiple bits may cause extra network round-trips. */
constant CURLOPT_HTTPAUTH  107

  // Set the ssl context callback function, currently only for OpenSSL ssl_ctx
  // in second argument. The function must be matching the
  // curl_ssl_ctx_callback proto. */
constant CURLOPT_SSL_CTX_FUNCTION  20108

  // Set the userdata for the ssl context callback function's third
  // argument */
constant CURLOPT_SSL_CTX_DATA  10109

  // FTP Option that causes missing dirs to be created on the remote server.
  // In 7.19.4 we introduced the convenience enums for this option using the
  // CURLFTP_CREATE_DIR prefix.

constant CURLOPT_FTP_CREATE_MISSING_DIRS  110

  // Set this to a bitmask value to enable the particular authentications
  // methods you like. Use this in combination with CURLOPT_PROXYUSERPWD.
  // Note that setting multiple bits may cause extra network round-trips. */
constant CURLOPT_PROXYAUTH  111

  // FTP option that changes the timeout, in seconds, associated with
  // getting a response.  This is different from transfer timeout time and
  // essentially places a demand on the FTP server to acknowledge commands
  // in a timely manner. */
constant CURLOPT_FTP_RESPONSE_TIMEOUT  112
constant CURLOPT_SERVER_RESPONSE_TIMEOUT 112

  // Set this option to one of the CURL_IPRESOLVE_* defines (see below) to
  // tell libcurl to resolve names to those IP versions only. This only has
  // affect on systems with support for more than one, i.e IPv4 _and_ IPv6. */
constant CURLOPT_IPRESOLVE  113

  // Set this option to limit the size of a file that will be downloaded from
  // an HTTP or FTP server.
  //
  // Note there is also _LARGE version which adds large file support for
  // platforms which have larger off_t sizes.  See MAXFILESIZE_LARGE below. */
constant CURLOPT_MAXFILESIZE  114

  // See the comment for INFILESIZE above, but in short, specifies
  // the size of the file being uploaded.  -1 means unknown.

constant CURLOPT_INFILESIZE_LARGE  30115

  // Sets the continuation offset.  There is also a LONG version of this;
  // look above for RESUME_FROM.

constant CURLOPT_RESUME_FROM_LARGE  30116

  // Sets the maximum size of data that will be downloaded from
  // an HTTP or FTP server.  See MAXFILESIZE above for the LONG version.

constant CURLOPT_MAXFILESIZE_LARGE  30117

  // Set this option to the file name of your .netrc file you want libcurl
  // to parse (using the CURLOPT_NETRC option). If not set, libcurl will do
  // a poor attempt to find the user's home directory and check for a .netrc
  // file in there. */
constant CURLOPT_NETRC_FILE  10118

  // Enable SSL/TLS for FTP, pick one of:
  // CURLFTPSSL_TRY     - try using SSL, proceed anyway otherwise
  // CURLFTPSSL_CONTROL - SSL for the control connection or fail
  // CURLFTPSSL_ALL     - SSL for all communication or fail

constant CURLOPT_USE_SSL  119

  // The _LARGE version of the standard POSTFIELDSIZE option */
constant CURLOPT_POSTFIELDSIZE_LARGE  30120

  // Enable/disable the TCP Nagle algorithm */
constant CURLOPT_TCP_NODELAY  121

  // 122 OBSOLETE, used in 7.12.3. Gone in 7.13.0 */
  // 123 OBSOLETE. Gone in 7.16.0 */
  // 124 OBSOLETE, used in 7.12.3. Gone in 7.13.0 */
  // 125 OBSOLETE, used in 7.12.3. Gone in 7.13.0 */
  // 126 OBSOLETE, used in 7.12.3. Gone in 7.13.0 */
  // 127 OBSOLETE. Gone in 7.16.0 */
  // 128 OBSOLETE. Gone in 7.16.0 */

  // When FTP over SSL/TLS is selected (with CURLOPT_USE_SSL this option
  // can be used to change libcurl's default action which is to first try
  // "AUTH SSL" and then "AUTH TLS" in this order, and proceed when a OK
  // response has been received.
  //
  // Available parameters are:
  // CURLFTPAUTH_DEFAULT - let libcurl decide
  // CURLFTPAUTH_SSL     - try "AUTH SSL" first, then TLS
  // CURLFTPAUTH_TLS     - try "AUTH TLS" first, then SSL
  
constant CURLOPT_FTPSSLAUTH  129

constant CURLOPT_IOCTLFUNCTION  20130
constant CURLOPT_IOCTLDATA  10131

  // 132 OBSOLETE. Gone in 7.16.0 */
  // 133 OBSOLETE. Gone in 7.16.0 */

  // zero terminated string for pass on to the FTP server when asked for
  // "account" info */
constant CURLOPT_FTP_ACCOUNT  10134

  // feed cookies into cookie engine */
constant CURLOPT_COOKIELIST  10135

  // ignore Content-Length */
constant CURLOPT_IGNORE_CONTENT_LENGTH  136

  // Set to non-zero to skip the IP address received in a 227 PASV FTP server
  // response. Typically used for FTP-SSL purposes but is not restricted to
  // that. libcurl will then instead use the same IP address it used for the
  // control connection. */
constant CURLOPT_FTP_SKIP_PASV_IP  137

  // Select "file method" to use when doing FTP, see the curl_ftpmethod
  // above. */
constant CURLOPT_FTP_FILEMETHOD  138

  // Local port number to bind the socket to */
constant CURLOPT_LOCALPORT  139

  // Number of ports to try, including the first one set with LOCALPORT.
  // Thus, setting it to 1 will make no additional attempts but the first.
  
constant CURLOPT_LOCALPORTRANGE  140

  // no transfer, set up connection and let application use the socket by
  // extracting it with CURLINFO_LASTSOCKET */
constant CURLOPT_CONNECT_ONLY  141

  // Function that will be called to convert from the
  // network encoding (instead of using the iconv calls in libcurl) */
constant CURLOPT_CONV_FROM_NETWORK_FUNCTION  20142

  // Function that will be called to convert to the
  // network encoding (instead of using the iconv calls in libcurl) */
constant CURLOPT_CONV_TO_NETWORK_FUNCTION  20143

  // Function that will be called to convert from UTF8
  // (instead of using the iconv calls in libcurl)
  // Note that this is used only for SSL certificate processing */
constant CURLOPT_CONV_FROM_UTF8_FUNCTION  20144

  // if the connection proceeds too quickly then need to slow it down */
  // limit-rate: maximum number of bytes per second to send or receive */
constant CURLOPT_MAX_SEND_SPEED_LARGE  30145
constant CURLOPT_MAX_RECV_SPEED_LARGE  30146

  // Pointer to command string to send if USER/PASS fails. */
constant CURLOPT_FTP_ALTERNATIVE_TO_USER  10147

  // callback function for setting socket options */
constant CURLOPT_SOCKOPTFUNCTION  20148
constant CURLOPT_SOCKOPTDATA  10149

  // set to 0 to disable session ID re-use for this transfer, default is
  // enabled (== 1) */
constant CURLOPT_SSL_SESSIONID_CACHE  150

  // allowed SSH authentication methods */
constant CURLOPT_SSH_AUTH_TYPES  151

  // Used by scp/sftp to do public/private key authentication */
constant CURLOPT_SSH_PUBLIC_KEYFILE  10152
constant CURLOPT_SSH_PRIVATE_KEYFILE  10153

  // Send CCC (Clear Command Channel) after authentication */
constant CURLOPT_FTP_SSL_CCC  154

  // Same as TIMEOUT and CONNECTTIMEOUT, but with ms resolution */
constant CURLOPT_TIMEOUT_MS  155
constant CURLOPT_CONNECTTIMEOUT_MS  156

  // set to zero to disable the libcurl's decoding and thus pass the raw body
  // data to the application even when it is encoded/compressed */
constant CURLOPT_HTTP_TRANSFER_DECODING  157
constant CURLOPT_HTTP_CONTENT_DECODING  158

  // Permission used when creating new files and directories on the remote
  // server for protocols that support it, SFTP/SCP/FILE */
constant CURLOPT_NEW_FILE_PERMS  159
constant CURLOPT_NEW_DIRECTORY_PERMS  160

  // Set the behaviour of POST when redirecting. Values must be set to one
  // of CURL_REDIR* defines below. This used to be called CURLOPT_POST301 */
constant CURLOPT_POSTREDIR  161

  // used by scp/sftp to verify the host's public key */
constant CURLOPT_SSH_HOST_PUBLIC_KEY_MD5  10162

  // Callback function for opening socket (instead of socket(2)). Optionally,
  // callback is able change the address or refuse to connect returning
  // CURL_SOCKET_BAD.  The callback should have type
  // curl_opensocket_callback */
constant CURLOPT_OPENSOCKETFUNCTION  20163
constant CURLOPT_OPENSOCKETDATA  10164

  // POST volatile input fields. */
constant CURLOPT_COPYPOSTFIELDS  10165

  // set transfer mode (;type=<a|i>) when doing FTP via an HTTP proxy */
constant CURLOPT_PROXY_TRANSFER_MODE  166

  // Callback function for seeking in the input stream */
constant CURLOPT_SEEKFUNCTION  20167
constant CURLOPT_SEEKDATA  10168

  // CRL file */
constant CURLOPT_CRLFILE  10169

  // Issuer certificate */
constant CURLOPT_ISSUERCERT  10170

  // (IPv6) Address scope */
constant CURLOPT_ADDRESS_SCOPE  171

  // Collect certificate chain info and allow it to get retrievable with
  // CURLINFO_CERTINFO after the transfer is complete. (Unfortunately) only
  // working with OpenSSL-powered builds. */
constant CURLOPT_CERTINFO  172

  // "name" and "pwd" to use when fetching. */
constant CURLOPT_USERNAME  10173
constant CURLOPT_PASSWORD  10174

  // "name" and "pwd" to use with Proxy when fetching. */
constant CURLOPT_PROXYUSERNAME  10175
constant CURLOPT_PROXYPASSWORD  10176

  // Comma separated list of hostnames defining no-proxy zones. These should
  // match both hostnames directly, and hostnames within a domain. For
  // example, local.com will match local.com and www.local.com, but NOT
  // notlocal.com or www.notlocal.com. For compatibility with other
  // implementations of this, .local.com will be considered to be the same as
  // local.com. A single * is the only valid wildcard, and effectively
  // disables the use of proxy. */
constant CURLOPT_NOPROXY  10177

  // block size for TFTP transfers */
constant CURLOPT_TFTP_BLKSIZE  178

  // Socks Service */
constant CURLOPT_SOCKS5_GSSAPI_SERVICE  10179

  // Socks Service */
constant CURLOPT_SOCKS5_GSSAPI_NEC  180

  // set the bitmask for the protocols that are allowed to be used for the
  // transfer, which thus helps the app which takes URLs from users or other
  // external inputs and want to restrict what protocol(s) to deal
  // with. Defaults to CURLPROTO_ALL. */
constant CURLOPT_PROTOCOLS  181

  // set the bitmask for the protocols that libcurl is allowed to follow to,
  // as a subset of the CURLOPT_PROTOCOLS ones. That means the protocol needs
  // to be set in both bitmasks to be allowed to get redirected to. Defaults
  // to all protocols except FILE and SCP. */
constant CURLOPT_REDIR_PROTOCOLS  182

  // set the SSH knownhost file name to use */
constant CURLOPT_SSH_KNOWNHOSTS  10183

  // set the SSH host key callback, must point to a curl_sshkeycallback
  // function */
constant CURLOPT_SSH_KEYFUNCTION  20184

  // set the SSH host key callback custom pointer */
constant CURLOPT_SSH_KEYDATA  10185

  // set the SMTP mail originator */
constant CURLOPT_MAIL_FROM  10186

  // set the SMTP mail receiver(s) */
constant CURLOPT_MAIL_RCPT  10187

  // FTP: send PRET before PASV */
constant CURLOPT_FTP_USE_PRET  188

  // RTSP request method (OPTIONS, SETUP, PLAY, etc...) */
constant CURLOPT_RTSP_REQUEST  189

  // The RTSP session identifier */
constant CURLOPT_RTSP_SESSION_ID  10190

  // The RTSP stream URI */
constant CURLOPT_RTSP_STREAM_URI  10191

  // The Transport: header to use in RTSP requests */
constant CURLOPT_RTSP_TRANSPORT  10192

  // Manually initialize the client RTSP CSeq for this handle */
constant CURLOPT_RTSP_CLIENT_CSEQ  193

  // Manually initialize the server RTSP CSeq for this handle */
constant CURLOPT_RTSP_SERVER_CSEQ  194

  // The stream to pass to INTERLEAVEFUNCTION. */
constant CURLOPT_INTERLEAVEDATA  10195

  // Let the application define a custom write method for RTP data */
constant CURLOPT_INTERLEAVEFUNCTION  20196

  // Turn on wildcard matching */
constant CURLOPT_WILDCARDMATCH  197

  // Directory matching callback called before downloading of an
  // individual file (chunk) started */
constant CURLOPT_CHUNK_BGN_FUNCTION  20198

  // Directory matching callback called after the file (chunk)
  // was downloaded, or skipped */
constant CURLOPT_CHUNK_END_FUNCTION  20199

  // Change match (fnmatch-like) callback for wildcard matching */
constant CURLOPT_FNMATCH_FUNCTION  20200

  // Let the application define custom chunk data pointer */
constant CURLOPT_CHUNK_DATA  10201

  // FNMATCH_FUNCTION user pointer */
constant CURLOPT_FNMATCH_DATA  10202

  // send linked-list of name:port:address sets */
constant CURLOPT_RESOLVE  10203

  // Set a username for authenticated TLS */
constant CURLOPT_TLSAUTH_USERNAME  10204

  // Set a password for authenticated TLS */
constant CURLOPT_TLSAUTH_PASSWORD  10205

  // Set authentication type for authenticated TLS */
constant CURLOPT_TLSAUTH_TYPE  10206

  // Set to 1 to enable the "TE:" header in HTTP requests to ask for
  // compressed transfer-encoded responses. Set to 0 to disable the use of TE:
  // in outgoing requests. The current default is 0, but it might change in a
  // future libcurl release.
  //
  // libcurl will ask for the compressed methods it knows of, and if that
  // isn't any, it will not ask for transfer-encoding at all even if this
  // option is set to 1.

constant CURLOPT_TRANSFER_ENCODING  207

  // Callback function for closing socket (instead of close(2)). The callback
  // should have type curl_closesocket_callback */
constant CURLOPT_CLOSESOCKETFUNCTION  20208
constant CURLOPT_CLOSESOCKETDATA  10209 

constant CURLINFO_LASTSOCKET     0x20001d

constant CURL_GLOBAL_NOTHING  0
constant CURL_GLOBAL_SSL      1
constant CURL_GLOBAL_WIN32    2
constant CURL_GLOBAL_ALL      3

// allow GSSAPI credential delegation */
constant CURLOPT_GSSAPI_DELEGATION 210

// Set the name servers to use for DNS resolution */
constant CURLOPT_DNS_SERVERS 211

// Time-out accept operations (currently for FTP only) after this amount
// of milliseconds. */
constant CURLOPT_ACCEPTTIMEOUT_MS 212

// Set TCP keepalive */
constant CURLOPT_TCP_KEEPALIVE 213

// non-universal keepalive knobs (Linux, AIX, HP-UX, more) */
constant CURLOPT_TCP_KEEPIDLE 214
constant CURLOPT_TCP_KEEPINTVL 215

// Enable/disable specific SSL features with a bitmask, see CURLSSLOPT_* */
constant CURLOPT_SSL_OPTIONS 216

// Set the SMTP auth originator */
constant CURLOPT_MAIL_AUTH 217

// Enable/disable SASL initial response */
constant CURLOPT_SASL_IR 218

// Function that will be called instead of the internal progress display
// function. This function should be defined as the curl_xferinfo_callback
// prototype defines. (Deprecates CURLOPT_PROGRESSFUNCTION) */
constant CURLOPT_XFERINFOFUNCTION 219

// The XOAUTH2 bearer token */
constant CURLOPT_XOAUTH2_BEARER 220

// Set the interface string to use as outgoing network
// interface for DNS requests.
// Only supported by the c-ares DNS backend */
constant CURLOPT_DNS_INTERFACE 221

// Set the local IPv4 address to use for outgoing DNS requests.
// Only supported by the c-ares DNS backend */
constant CURLOPT_DNS_LOCAL_IP4 222

// Set the local IPv6 address to use for outgoing DNS requests.
// Only supported by the c-ares DNS backend */
constant CURLOPT_DNS_LOCAL_IP6 223

// Set authentication options directly */
constant CURLOPT_LOGIN_OPTIONS 224

// Enable/disable TLS NPN extension (http2 over ssl might fail without) */
constant CURLOPT_SSL_ENABLE_NPN 225

// Enable/disable TLS ALPN extension (http2 over ssl might fail without) */
constant CURLOPT_SSL_ENABLE_ALPN 226

// Time to wait for a response to a HTTP request containing an
// Expect: 100-continue header before sending the data anyway. */
constant CURLOPT_EXPECT_100_TIMEOUT_MS 227

// This points to a linked list of headers used for proxy requests only,
// struct curl_slist kind */
constant CURLOPT_PROXYHEADER 228

// Pass in a bitmask of "header options" */
constant CURLOPT_HEADEROPT 229

// The public key in DER form used to validate the peer public key
// this option is used only if SSL_VERIFYPEER is true */
constant CURLOPT_PINNEDPUBLICKEY 230

// Path to Unix domain socket */
constant CURLOPT_UNIX_SOCKET_PATH 231

// Set if we should verify the certificate status. */
constant CURLOPT_SSL_VERIFYSTATUS 232

// Set if we should enable TLS false start. */
constant CURLOPT_SSL_FALSESTART 233

// Do not squash dot-dot sequences */
constant CURLOPT_PATH_AS_IS 234

// Proxy Service Name */
constant CURLOPT_PROXY_SERVICE_NAME 235

// Service Name */
constant CURLOPT_SERVICE_NAME 236

// Wait/don't wait for pipe/mutex to clarify */
constant CURLOPT_PIPEWAIT 237

// Set the protocol used when curl is given a URL without a protocol */
constant CURLOPT_DEFAULT_PROTOCOL 238

// Set stream weight, 1 - 256 (default is 16) */
constant CURLOPT_STREAM_WEIGHT 239

// Set stream dependency on another CURL handle */
constant CURLOPT_STREAM_DEPENDS 240

// Set E-xclusive stream dependency on another CURL handle */
constant CURLOPT_STREAM_DEPENDS_E 241

// Do not send any tftp option requests to the server */
constant CURLOPT_TFTP_NO_OPTIONS 242

// Linked-list of host:port:connect-to-host:connect-to-port,
// overrides the URL's host:port (only for the network layer) */
constant CURLOPT_CONNECT_TO 243

// Set TCP Fast Open */
constant CURLOPT_TCP_FASTOPEN 244

// Continue to send data if the server responds early with an
//  HTTP status code >= 300 */
constant CURLOPT_KEEP_SENDING_ON_ERROR 245

// The CApath or CAfile used to validate the proxy certificate
// this option is used only if PROXY_SSL_VERIFYPEER is true */
constant CURLOPT_PROXY_CAINFO 246

// The CApath directory used to validate the proxy certificate
// this option is used only if PROXY_SSL_VERIFYPEER is true */
constant CURLOPT_PROXY_CAPATH 247

// Set if we should verify the proxy in ssl handshake,
// set 1 to verify. */
constant CURLOPT_PROXY_SSL_VERIFYPEER 248

// Set if we should verify the Common name from the proxy certificate in ssl
// handshake, set 1 to check existence, 2 to ensure that it matches
// the provided hostname. */
constant CURLOPT_PROXY_SSL_VERIFYHOST 249

// What version to specifically try to use for proxy.
// See CURL_SSLVERSION defines below. */
constant CURLOPT_PROXY_SSLVERSION 250

// Set a username for authenticated TLS for proxy */
constant CURLOPT_PROXY_TLSAUTH_USERNAME 251

// Set a password for authenticated TLS for proxy */
constant CURLOPT_PROXY_TLSAUTH_PASSWORD 252

// Set authentication type for authenticated TLS for proxy */
constant CURLOPT_PROXY_TLSAUTH_TYPE 253

// name of the file keeping your private SSL-certificate for proxy */
constant CURLOPT_PROXY_SSLCERT 254

// type of the file keeping your SSL-certificate ("DER", "PEM", "ENG") for
// proxy */
constant CURLOPT_PROXY_SSLCERTTYPE 255

// name of the file keeping your private SSL-key for proxy */
constant CURLOPT_PROXY_SSLKEY 256

// type of the file keeping your private SSL-key ("DER", "PEM", "ENG") for
// proxy */
constant CURLOPT_PROXY_SSLKEYTYPE 257

// password for the SSL private key for proxy */
constant CURLOPT_PROXY_KEYPASSWD 258

// Specify which SSL ciphers to use for proxy */
constant CURLOPT_PROXY_SSL_CIPHER_LIST 259

// CRL file for proxy */
constant CURLOPT_PROXY_CRLFILE 260

// Enable/disable specific SSL features with a bitmask for proxy, see
// CURLSSLOPT_* */
constant CURLOPT_PROXY_SSL_OPTIONS 261

// Name of pre proxy to use. */
constant CURLOPT_PRE_PROXY 262

// The public key in DER form used to validate the proxy public key
// this option is used only if PROXY_SSL_VERIFYPEER is true */
constant CURLOPT_PROXY_PINNEDPUBLICKEY 263

// Path to an abstract Unix domain socket */
constant CURLOPT_ABSTRACT_UNIX_SOCKET 264

// Suppress proxy CONNECT response headers from user callbacks */
constant CURLOPT_SUPPRESS_CONNECT_HEADERS 265

// The request target, instead of extracted from the URL */
constant CURLOPT_REQUEST_TARGET 266

// bitmask of allowed auth methods for connections to SOCKS5 proxies */
constant CURLOPT_SOCKS5_AUTH 267

// Enable/disable SSH compression */
constant CURLOPT_SSH_COMPRESSION 268

// Post MIME data. */
constant CURLOPT_MIMEPOST 10269

// Time to use with the CURLOPT_TIMECONDITION. Specified in number of
// seconds since 1 Jan 1970. */
constant CURLOPT_TIMEVALUE_LARGE 270

// Head start in milliseconds to give happy eyeballs. */
constant CURLOPT_HAPPY_EYEBALLS_TIMEOUT_MS 271

// Function that will be called before a resolver request is made */
constant CURLOPT_RESOLVER_START_FUNCTION 272

// User data to pass to the resolver start callback. */
constant CURLOPT_RESOLVER_START_DATA 273

// send HAProxy PROXY protocol header? */
constant CURLOPT_HAPROXYPROTOCOL 274

// shuffle addresses before use when DNS returns multiple */
constant CURLOPT_DNS_SHUFFLE_ADDRESSES 275

// Specify which TLS 1.3 ciphers suites to use */
constant CURLOPT_TLS13_CIPHERS 276
constant CURLOPT_PROXY_TLS13_CIPHERS 277

// Disallow specifying username/login in URL. */
constant CURLOPT_DISALLOW_USERNAME_IN_URL 278

// DNS-over-HTTPS URL */
constant CURLOPT_DOH_URL 279

// Preferred buffer size to use for uploads */
constant CURLOPT_UPLOAD_BUFFERSIZE 280

// Time in ms between connection upkeep calls for long-lived connections. */
constant CURLOPT_UPKEEP_INTERVAL_MS 281

// Specify URL using CURL URL API. */
constant CURLOPT_CURLU 282

// add trailing data just after no more data is available */
constant CURLOPT_TRAILERFUNCTION 283

// pointer to be passed to HTTP_TRAILER_FUNCTION */
constant CURLOPT_TRAILERDATA 284

// set this to 1L to allow HTTP/0.9 responses or 0L to disallow */
constant CURLOPT_HTTP09_ALLOWED 285

// alt-svc control bitmask */
constant CURLOPT_ALTSVC_CTRL 286

// alt-svc cache file name to possibly read from/write to */
constant CURLOPT_ALTSVC 287

// maximum age of a connection to consider it for reuse (in seconds) */
constant CURLOPT_MAXAGE_CONN 288

// SASL authorisation identity */
constant CURLOPT_SASL_AUTHZID 289

// allow RCPT TO command to fail for some recipients */
constant CURLOPT_MAIL_RCPT_ALLLOWFAILS 290

// the private SSL-certificate as a "blob" */
constant CURLOPT_SSLCERT_BLOB 291
constant CURLOPT_SSLKEY_BLOB 292
constant CURLOPT_PROXY_SSLCERT_BLOB 293
constant CURLOPT_PROXY_SSLKEY_BLOB 294
constant CURLOPT_ISSUERCERT_BLOB 295

// Issuer certificate for proxy */
constant CURLOPT_PROXY_ISSUERCERT 296
constant CURLOPT_PROXY_ISSUERCERT_BLOB 297

// the EC curves requested by the TLS client (RFC 8422, 5.1);
// OpenSSL support via 'set_groups'/'set_curves':
// https://www.openssl.org/docs/manmaster/man3/SSL_CTX_set1_groups.html
constant CURLOPT_SSL_EC_CURVES 298
